@@ -22,6 +22,14 @@
  
 #include <config.h>
 
+/**
+ * SECTION:glade-utils
+ * @Title: Glade Utils
+ * @Short_Description: Welcome to the zoo.
+ *
+ * This is where all of that really usefull miscalanious stuff lands up.
+ */
+
 #include "glade.h"
 #include "glade-project.h"
 #include "glade-command.h"
@@ -35,7 +43,6 @@
 #include "glade-fixed.h"
 
 #include <string.h>
-#include <gtk/gtktooltips.h>
 #include <gdk/gdkkeysyms.h>
 #include <gmodule.h>
 #include <glib/gi18n-lib.h>
@@ -58,33 +65,6 @@
  */
 static GList *glade_util_selection = NULL;
 
-static GtkTooltips *glade_tooltips = NULL;
-
-/**
- * glade_util_widget_set_tooltip:
- * @widget: a #GtkWidget
- * @str: a string
- *
- * Creates a new tooltip from @str and sets @widget to use it.
- */
-void
-glade_util_widget_set_tooltip (GtkWidget *widget, const gchar *str)
-{
-	g_return_if_fail (widget != NULL);
-	if (str == NULL)
-		return;
-
-	if (glade_tooltips == NULL)
-	{
-		glade_tooltips = gtk_tooltips_new ();
-	
-		g_object_ref (G_OBJECT (glade_tooltips));
-		gtk_object_sink (GTK_OBJECT (glade_tooltips));	
-	}
-
-	gtk_tooltips_set_tip (glade_tooltips, widget, str, NULL);
-}
-
 /**
  * glade_util_compose_get_type_func:
  * @name:
@@ -504,18 +484,85 @@ glade_util_hide_window (GtkWindow *window)
 	gtk_window_move(window, x, y);
 }
 
+
+static void
+format_libglade_button_clicked (GtkWidget *widget,
+				GladeProject *project)
+{
+	glade_project_set_format (project, GLADE_PROJECT_FORMAT_LIBGLADE);
+}
+
+static void
+format_builder_button_clicked (GtkWidget *widget,
+			       GladeProject *project)
+{
+	glade_project_set_format (project, GLADE_PROJECT_FORMAT_GTKBUILDER);
+}
+
+static void
+add_format_options (GtkDialog    *dialog,
+		    GladeProject *project)
+{
+	GtkWidget *vbox, *frame;
+	GtkWidget *glade_radio, *builder_radio;
+	GtkWidget *label, *alignment;
+	gchar     *string = g_strdup_printf ("<b>%s</b>", _("Select file format"));
+
+	frame = gtk_frame_new (NULL);
+	vbox = gtk_vbox_new (FALSE, 0);
+	alignment = gtk_alignment_new (0.5F, 0.5F, 1.0F, 1.0F);
+
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 2, 0, 12, 0);
+
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+
+	label = gtk_label_new (string);
+	g_free (string);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+
+	glade_radio = gtk_radio_button_new_with_label (NULL, "Libglade");
+	builder_radio = gtk_radio_button_new_with_label_from_widget
+		(GTK_RADIO_BUTTON (glade_radio), "GtkBuilder");
+
+	if (glade_project_get_format (project) == GLADE_PROJECT_FORMAT_GTKBUILDER)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (builder_radio), TRUE);
+	else
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (glade_radio), TRUE);
+
+	g_signal_connect (G_OBJECT (glade_radio), "clicked",
+			  G_CALLBACK (format_libglade_button_clicked), project);
+
+	g_signal_connect (G_OBJECT (builder_radio), "clicked",
+			  G_CALLBACK (format_builder_button_clicked), project);
+
+	gtk_box_pack_start (GTK_BOX (vbox), builder_radio, TRUE, TRUE, 2);
+	gtk_box_pack_start (GTK_BOX (vbox), glade_radio, TRUE, TRUE, 2);
+
+	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+	gtk_container_add (GTK_CONTAINER (alignment), vbox);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+
+	gtk_widget_show_all (frame);
+	
+	gtk_box_pack_end (GTK_BOX (dialog->vbox), frame, FALSE, TRUE, 2);
+}
+
+
 /**
  * glade_util_file_dialog_new:
  * @title: dialog title
- * @parent: the parent #GtkWindow for the dialog
+ * @project: a #GladeProject used when saving
+ * @parent: a parent #GtkWindow for the dialog
  * @action: a #GladeUtilFileDialogType to say if the dialog will open or save
  *
  * Returns: a "glade file" file chooser dialog. The caller is responsible 
  *          for showing the dialog
  */
 GtkWidget *
-glade_util_file_dialog_new (const gchar *title, GtkWindow *parent, 
-			     GladeUtilFileDialogType action)
+glade_util_file_dialog_new (const gchar             *title, 
+			    GladeProject            *project,
+			    GtkWindow               *parent, 
+			    GladeUtilFileDialogType  action)
 {
 	GtkWidget *file_dialog;
 	GtkFileFilter *file_filter;
@@ -523,6 +570,9 @@ glade_util_file_dialog_new (const gchar *title, GtkWindow *parent,
 	g_return_val_if_fail ((action == GLADE_FILE_DIALOG_ACTION_OPEN ||
 			       action == GLADE_FILE_DIALOG_ACTION_SAVE), NULL);
 	
+	g_return_val_if_fail ((action != GLADE_FILE_DIALOG_ACTION_SAVE ||
+			       GLADE_IS_PROJECT (project)), NULL);
+
 	file_dialog = gtk_file_chooser_dialog_new (title, parent, action,
 						   GTK_STOCK_CANCEL,
 						   GTK_RESPONSE_CANCEL,
@@ -530,6 +580,10 @@ glade_util_file_dialog_new (const gchar *title, GtkWindow *parent,
 						   GTK_STOCK_OPEN : GTK_STOCK_SAVE,
 						   GTK_RESPONSE_OK,
 						   NULL);
+
+
+	if (action == GLADE_FILE_DIALOG_ACTION_SAVE)
+		add_format_options (GTK_DIALOG (file_dialog), project);
 	
 	file_filter = gtk_file_filter_new ();
 	gtk_file_filter_add_pattern (file_filter, "*");
@@ -538,7 +592,18 @@ glade_util_file_dialog_new (const gchar *title, GtkWindow *parent,
 
 	file_filter = gtk_file_filter_new ();
 	gtk_file_filter_add_pattern (file_filter, "*.glade");
-	gtk_file_filter_set_name (file_filter, _("Glade Files"));
+	gtk_file_filter_set_name (file_filter, _("Libglade Files"));
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_dialog), file_filter);
+
+	file_filter = gtk_file_filter_new ();
+	gtk_file_filter_add_pattern (file_filter, "*.ui");
+	gtk_file_filter_set_name (file_filter, _("GtkBuilder Files"));
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_dialog), file_filter);
+
+	file_filter = gtk_file_filter_new ();
+	gtk_file_filter_add_pattern (file_filter, "*.ui");
+	gtk_file_filter_add_pattern (file_filter, "*.glade");
+	gtk_file_filter_set_name (file_filter, _("All Glade Files"));
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_dialog), file_filter);
 
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (file_dialog), file_filter);
@@ -589,15 +654,6 @@ glade_util_read_prop_name (const gchar *str)
 
 	glade_util_replace (id, '_', '-');
 
-	if (strstr (id, "::"))
-	{
-		/* Extract the second half of "AtkObject::accessible_name"
-		 */
-		gchar **split = g_strsplit (id, "::", 0);
-		g_free (id);
-		id = g_strdup (split[1]);
-		g_strfreev (split);
-	}
 	return id;
 }
 
@@ -968,7 +1024,7 @@ glade_util_container_get_all_children (GtkContainer *container)
  * glade_util_count_placeholders:
  * @parent: a #GladeWidget
  *
- * Returns the amount of #GladePlaceholders parented by @parent
+ * Returns: the amount of #GladePlaceholders parented by @parent
  */
 gint
 glade_util_count_placeholders (GladeWidget *parent)
@@ -1106,8 +1162,8 @@ glade_util_purify_list (GList *list)
 
 /**
  * glade_util_added_in_list:
- * @old: the old #GList
- * @new: the new #GList
+ * @old_list: the old #GList
+ * @new_list: the new #GList
  *
  * Returns: A newly allocated #GList of elements that
  *          are in @new but not in @old
@@ -1130,8 +1186,8 @@ glade_util_added_in_list (GList *old_list,
 
 /**
  * glade_util_removed_from_list:
- * @old: the old #GList
- * @new: the new #GList
+ * @old_list: the old #GList
+ * @new_list: the new #GList
  *
  * Returns: A newly allocated #GList of elements that
  *          are in @old no longer in @new
